@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) 2016-2022 by the Free Software Foundation, Inc.
+# Copyright (C) 2016-2023 by the Free Software Foundation, Inc.
 #
 # This file is part of Postorius.
 #
@@ -22,7 +22,7 @@ from django.apps import AppConfig
 
 class PostoriusConfig(AppConfig):
     name = 'postorius'
-    verbose_name = "Postorius"
+    verbose_name = 'Postorius'
 
     def ready(self):
         import postorius.signals  # noqa: F401
